"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.genesisAuthStoreSchema = exports.genesisLegacyStoreSchema = exports.voteWeightsSchema = exports.blockHeaderSchema = exports.signingBlockHeaderSchema = exports.accountSchema = exports.unregisteredAddressesSchema = void 0;
exports.unregisteredAddressesSchema = {
    $id: '/legacyAccount/unregisteredAddresses',
    type: 'object',
    properties: {
        unregisteredAddresses: {
            type: 'array',
            fieldNumber: 1,
            items: {
                type: 'object',
                properties: {
                    address: {
                        dataType: 'bytes',
                        fieldNumber: 1,
                    },
                    balance: {
                        dataType: 'uint64',
                        fieldNumber: 2,
                    },
                },
                required: ['address', 'balance'],
            },
        },
    },
    required: ['unregisteredAddresses'],
};
exports.accountSchema = {
    $id: '/account/base',
    type: 'object',
    properties: {
        address: {
            dataType: 'bytes',
            fieldNumber: 1,
        },
        token: {
            type: 'object',
            properties: {
                balance: {
                    fieldNumber: 1,
                    dataType: 'uint64',
                },
            },
            fieldNumber: 2,
        },
        sequence: {
            type: 'object',
            properties: {
                nonce: {
                    fieldNumber: 1,
                    dataType: 'uint64',
                },
            },
            fieldNumber: 3,
        },
        keys: {
            type: 'object',
            properties: {
                numberOfSignatures: {
                    dataType: 'uint32',
                    fieldNumber: 1,
                },
                mandatoryKeys: {
                    type: 'array',
                    items: {
                        dataType: 'bytes',
                    },
                    fieldNumber: 2,
                },
                optionalKeys: {
                    type: 'array',
                    items: {
                        dataType: 'bytes',
                    },
                    fieldNumber: 3,
                },
            },
            fieldNumber: 4,
        },
        dpos: {
            type: 'object',
            properties: {
                delegate: {
                    type: 'object',
                    fieldNumber: 1,
                    properties: {
                        username: {
                            dataType: 'string',
                            fieldNumber: 1,
                        },
                        pomHeights: {
                            type: 'array',
                            items: {
                                dataType: 'uint32',
                            },
                            fieldNumber: 2,
                        },
                        consecutiveMissedBlocks: {
                            dataType: 'uint32',
                            fieldNumber: 3,
                        },
                        lastForgedHeight: {
                            dataType: 'uint32',
                            fieldNumber: 4,
                        },
                        isBanned: {
                            dataType: 'boolean',
                            fieldNumber: 5,
                        },
                        totalVotesReceived: {
                            dataType: 'uint64',
                            fieldNumber: 6,
                        },
                    },
                    required: [
                        'username',
                        'pomHeights',
                        'consecutiveMissedBlocks',
                        'lastForgedHeight',
                        'isBanned',
                        'totalVotesReceived',
                    ],
                },
                sentVotes: {
                    type: 'array',
                    fieldNumber: 2,
                    items: {
                        type: 'object',
                        properties: {
                            delegateAddress: {
                                dataType: 'bytes',
                                fieldNumber: 1,
                            },
                            amount: {
                                dataType: 'uint64',
                                fieldNumber: 2,
                            },
                        },
                        required: ['delegateAddress', 'amount'],
                    },
                },
                unlocking: {
                    type: 'array',
                    fieldNumber: 3,
                    items: {
                        type: 'object',
                        properties: {
                            delegateAddress: {
                                dataType: 'bytes',
                                fieldNumber: 1,
                            },
                            amount: {
                                dataType: 'uint64',
                                fieldNumber: 2,
                            },
                            unvoteHeight: {
                                dataType: 'uint32',
                                fieldNumber: 3,
                            },
                        },
                        required: ['delegateAddress', 'amount', 'unvoteHeight'],
                    },
                },
            },
            fieldNumber: 5,
        },
    },
    required: ['address', 'token', 'sequence', 'keys', 'dpos'],
};
exports.signingBlockHeaderSchema = {
    $id: '/block/header/signing',
    type: 'object',
    properties: {
        version: { dataType: 'uint32', fieldNumber: 1 },
        timestamp: { dataType: 'uint32', fieldNumber: 2 },
        height: { dataType: 'uint32', fieldNumber: 3 },
        previousBlockID: { dataType: 'bytes', fieldNumber: 4 },
        transactionRoot: { dataType: 'bytes', fieldNumber: 5 },
        generatorPublicKey: { dataType: 'bytes', fieldNumber: 6 },
        reward: { dataType: 'uint64', fieldNumber: 7 },
        asset: { dataType: 'bytes', fieldNumber: 8 },
    },
    required: [
        'version',
        'timestamp',
        'height',
        'previousBlockID',
        'transactionRoot',
        'generatorPublicKey',
        'reward',
        'asset',
    ],
};
exports.blockHeaderSchema = {
    ...exports.signingBlockHeaderSchema,
    $id: '/block/header',
    properties: {
        ...exports.signingBlockHeaderSchema.properties,
        signature: { dataType: 'bytes', fieldNumber: 9 },
    },
};
exports.voteWeightsSchema = {
    $id: '/dpos/voteWeights',
    type: 'object',
    properties: {
        voteWeights: {
            type: 'array',
            fieldNumber: 1,
            items: {
                type: 'object',
                properties: {
                    round: {
                        dataType: 'uint32',
                        fieldNumber: 1,
                    },
                    delegates: {
                        type: 'array',
                        fieldNumber: 2,
                        items: {
                            type: 'object',
                            properties: {
                                address: {
                                    dataType: 'bytes',
                                    fieldNumber: 1,
                                },
                                voteWeight: {
                                    dataType: 'uint64',
                                    fieldNumber: 2,
                                },
                            },
                        },
                    },
                },
            },
        },
    },
    required: ['voteWeights'],
};
exports.genesisLegacyStoreSchema = {
    $id: '/legacy/module/genesis',
    type: 'object',
    required: ['accounts'],
    properties: {
        accounts: {
            type: 'array',
            fieldNumber: 1,
            items: {
                type: 'object',
                required: ['address', 'balance'],
                properties: {
                    address: {
                        dataType: 'bytes',
                        minLength: 8,
                        maxLength: 8,
                        fieldNumber: 1,
                    },
                    balance: {
                        dataType: 'uint64',
                        fieldNumber: 2,
                    },
                },
            },
        },
    },
};
exports.genesisAuthStoreSchema = {
    $id: '/auth/module/genesis',
    type: 'object',
    required: ['authDataSubstore'],
    properties: {
        authDataSubstore: {
            type: 'array',
            fieldNumber: 1,
            items: {
                type: 'object',
                required: ['address', 'authAccount'],
                properties: {
                    address: {
                        dataType: 'bytes',
                        format: 'lisk32',
                        fieldNumber: 1,
                    },
                    authAccount: {
                        type: 'object',
                        fieldNumber: 2,
                        required: ['nonce', 'numberOfSignatures', 'mandatoryKeys', 'optionalKeys'],
                        properties: {
                            nonce: {
                                dataType: 'uint64',
                                fieldNumber: 1,
                            },
                            numberOfSignatures: {
                                dataType: 'uint32',
                                fieldNumber: 2,
                            },
                            mandatoryKeys: {
                                type: 'array',
                                fieldNumber: 3,
                                items: {
                                    dataType: 'bytes',
                                },
                            },
                            optionalKeys: {
                                type: 'array',
                                fieldNumber: 4,
                                items: {
                                    dataType: 'bytes',
                                },
                            },
                        },
                    },
                },
            },
        },
    },
};
//# sourceMappingURL=schemas.js.map