"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTransactionPublicKeySet = exports.incrementOne = exports.keyString = void 0;
const lisk_codec_1 = require("@liskhq/lisk-codec");
const lisk_chain_1 = require("@liskhq/lisk-chain");
const constants_1 = require("../constants");
const keyString = (key) => key.toString('binary');
exports.keyString = keyString;
const incrementOne = (input) => {
    const copiedInput = Buffer.alloc(input.length);
    input.copy(copiedInput);
    for (let i = copiedInput.length - 1; i >= 0; i -= 1) {
        const sum = copiedInput[i] + 1;
        copiedInput[i] = sum & 0xff;
        if (sum <= 0xff) {
            return copiedInput;
        }
    }
    throw new Error('input is already maximum at the size');
};
exports.incrementOne = incrementOne;
const getTransactionPublicKeySet = async (db, pageSize) => {
    const result = new Set();
    let startingKey = Buffer.from(`${constants_1.DB_KEY_TRANSACTIONS_ID}:${(0, exports.keyString)(Buffer.alloc(32, 0))}`);
    while (true) {
        let exist = false;
        const txsStream = db.createReadStream({
            gte: startingKey,
            lte: Buffer.from(`${constants_1.DB_KEY_TRANSACTIONS_ID}:${(0, exports.keyString)(Buffer.alloc(32, 255))}`),
            limit: pageSize,
        });
        let lastKey = startingKey;
        await new Promise((resolve, reject) => {
            txsStream
                .on('data', async ({ key, value }) => {
                exist = true;
                const tx = await lisk_codec_1.codec.decode(lisk_chain_1.transactionSchema, value);
                result.add(tx.senderPublicKey.toString('hex'));
                lastKey = key;
            })
                .on('error', error => {
                reject(error);
            })
                .on('end', () => {
                resolve();
            });
        });
        if (!exist) {
            break;
        }
        startingKey = (0, exports.incrementOne)(lastKey);
    }
    return result;
};
exports.getTransactionPublicKeySet = getTransactionPublicKeySet;
//# sourceMappingURL=transaction.js.map